Struct proptest_quickcheck_interop::QCStrategy
[−]
[src]
pub struct QCStrategy<A: Arbitrary + Debug> { /* fields omitted */ }
QCStrategy is a Strategy that provides interoperability with
quickcheck's Arbitrary trait. If you have any type implementing
Arbitrary and Debug, which a temporary requirement, then you may
get back the equivalent Strategy in proptest.
Methods
impl<A: Arbitrary + Debug> QCStrategy<A>[src]
fn new(size: usize) -> Self[src]
Constructs a new QCStrategy given a size parameter that:
controls the size of random values generated. For example, it specifies the maximum length of a randomly generated vector and also will specify the maximum magnitude of a randomly generated number.
as defined by quickcheck